4.21. umbra.components.factory.scriptEditor.searchInFiles — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.21. umbra.components.factory.scriptEditor.searchInFiles

searchInFiles.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `SearchInFiles` class.

Others:

## 4.21.1. Module Attributes

`umbra.components.factory.scriptEditor.searchInFiles.` `LOGGER`

`umbra.components.factory.scriptEditor.searchInFiles.` `UI_FILE`

## 4.21.2. Classes

class `umbra.components.factory.scriptEditor.searchInFiles.` `SearchInFiles`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  This class defines search and replace in files dialog used by the ScriptEditor Component.

  Parameters: | parent – Object parent. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `scriptEditor`

    This method is the property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor. ( QWidget )

  `filesCache`

    This method is the property for self.__filesCache attribute.

    Returns: | self.__filesCache. ( Cache )

  `searchPatternsModel`

    This method is the property for self.__searchPatternsModel attribute.

    Returns: | self.__searchPatternsModel. ( PatternsModel )

  `replaceWithPatternsModel`

    This method is the property for self.__replaceWithPatternsModel attribute.

    Returns: | self.__replaceWithPatternsModel. ( PatternsModel )

  `model`

    This method is the property for self.__model attribute.

    Returns: | self.__model. ( SearchResultsModel )

  `view`

    This method is the property for self.__view attribute.

    Returns: | self.__view. ( QWidget )

  `delegate`

    This method is the property for self.__delegate attribute.

    Returns: | self.__delegate. ( QItemDelegate )

  `locations`

    This method is the property for self.__locations attribute.

    Returns: | self.__locations. ( OrderedDict )

  `locationsMenu`

    This method is the property for self.__locationsMenu attribute.

    Returns: | self.__locationsMenu. ( QMenu )

  `defaultFilterIn`

    This method is the property for self.__defaultFilterIn attribute.

    Returns: | self.__defaultFilterIn. ( String )

  `filtersInFormat`

    This method is the property for self.__filtersInFormat attribute.

    Returns: | self.__filtersInFormat. ( String )

  `defaultFilterOut`

    This method is the property for self.__defaultFilterOut attribute.

    Returns: | self.__defaultFilterOut. ( String )

  `filtersOutFormat`

    This method is the property for self.__filtersOutFormat attribute.

    Returns: | self.__filtersOutFormat. ( String )

  `defaultTarget`

    This method is the property for self.__defaultTarget attribute.

    Returns: | self.__defaultTarget. ( String )

  `targetsFormat`

    This method is the property for self.__targetsFormat attribute.

    Returns: | self.__targetsFormat. ( String )

  `defaultLineNumberWidth`

    This method is the property for self.__defaultLineNumberWidth attribute.

    Returns: | self.__defaultLineNumberWidth. ( Integer )

  `defaultLineColor`

    This method is the property for self.__defaultLineColor attribute.

    Returns: | self.__defaultLineColor. ( QColor )

  `ignoreHiddenFiles`

    This method is the property for self.__ignoreHiddenFiles attribute.

    Returns: | self.__ignoreHiddenFiles. ( Boolean )

  `searchWorkerThread`

    This method is the property for self.__searchWorkerThread attribute.

    Returns: | self.__searchWorkerThread. ( QThread )

  `show`()

    This method reimplements the `QWidget.show()` method.

  `closeEvent`(event)

    This method reimplements the `QWidget.closeEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `setSearchResults`(searchResults)

    This method sets the Model Nodes using given search results.

    Parameters: | searchResults – Search results. ( List )
    Returns: | Method success. ( Boolean )

  `setReplaceResults`(replaceResults)

    This method sets the Model Nodes using given replace results.

    Parameters: | replaceResults – Replace results. ( List )
    Returns: | Method success. ( Boolean )

  `search`()

    This method searchs user defined locations for search pattern.

    Returns: | Method success. ( Boolean )

  `replace`(nodes)

    This method replaces user defined files search pattern occurences with replacement pattern using given nodes.

    Parameters: | nodes – Nodes. ( List )
    Returns: | Method success. ( Boolean )

  `saveFiles`(nodes)

    This method saves user defined files using give nodes.

    Parameters: | nodes – Nodes. ( List )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »